@@ -6,7 +6,9 @@ pub struct PickCommand;
 
 impl GenericCommand for PickCommand {
     fn run(&self, out: &mut Output, matches: &ArgMatches, config: &Config) -> Result<()> {
-        let count = matches.value_of("count").expect("required argument");
+        let count = matches
+            .get_one::<String>("count")
+            .expect("required argument");
         let count = count
             .parse::<usize>()
             .map_err(|_| PastelError::CouldNotParseNumber(count.into()))?;
