@@ -1,10 +1,10 @@
 use crate::Color;
 
-use rand::prelude::*;
+use rand::{prelude::*, rng};
 
 pub trait RandomizationStrategy {
     fn generate(&mut self) -> Color {
-        self.generate_with(&mut thread_rng())
+        self.generate_with(&mut rng())
     }
 
     fn generate_with(&mut self, r: &mut dyn RngCore) -> Color;
@@ -20,9 +20,9 @@ pub mod strategies {
 
     impl RandomizationStrategy for Vivid {
         fn generate_with(&mut self, rng: &mut dyn RngCore) -> Color {
-            let hue = rng.gen::<f64>() * 360.0;
-            let saturation = 0.2 + 0.6 * rng.gen::<f64>();
-            let lightness = 0.3 + 0.4 * rng.gen::<f64>();
+            let hue = rng.random::<f64>() * 360.0;
+            let saturation = 0.2 + 0.6 * rng.random::<f64>();
+            let lightness = 0.3 + 0.4 * rng.random::<f64>();
 
             Color::from_hsl(hue, saturation, lightness)
         }
@@ -32,7 +32,7 @@ pub mod strategies {
 
     impl RandomizationStrategy for UniformRGB {
         fn generate_with(&mut self, rng: &mut dyn RngCore) -> Color {
-            Color::from_rgb(rng.gen::<u8>(), rng.gen::<u8>(), rng.gen::<u8>())
+            Color::from_rgb(rng.random::<u8>(), rng.random::<u8>(), rng.random::<u8>())
         }
     }
 
@@ -40,7 +40,7 @@ pub mod strategies {
 
     impl RandomizationStrategy for UniformGray {
         fn generate_with(&mut self, rng: &mut dyn RngCore) -> Color {
-            Color::graytone(rng.gen::<f64>())
+            Color::graytone(rng.random::<f64>())
         }
     }
 
@@ -48,7 +48,7 @@ pub mod strategies {
 
     impl RandomizationStrategy for UniformHueLCh {
         fn generate_with(&mut self, rng: &mut dyn RngCore) -> Color {
-            Color::from_lch(70.0, 35.0, 360.0 * rng.gen::<f64>(), 1.0)
+            Color::from_lch(70.0, 35.0, 360.0 * rng.random::<f64>(), 1.0)
         }
     }
 }
